@@ -38,9 +38,9 @@ Julian_Date_of_Year(double year)
   A = i;
   i = A / 4;
   B = 2 - A + i;
-  i = (int)(365.25 * year);
-  i += 30.6001 * 14;
-  jdoy = i + 1720994.5 + B;
+  i = (long)(365.25 * year);
+  i += (long)( 30.6001 * 14.0 );
+  jdoy = (double)i + 1720994.5 + (double)B;
 
   return (jdoy);
 
@@ -67,9 +67,9 @@ Julian_Date_of_Epoch( double epoch )
   /* Valid 1957 through 2056     */
   day = modf(epoch*1E-3, &year)*1E3;
   if( year < 57 )
-	year = year + 2000;
+    year = year + 2000;
   else
-	year = year + 1900;
+    year = year + 1900;
   /* End modification */
 
   return( Julian_Date_of_Year(year) + day );
@@ -118,12 +118,12 @@ DOY(int yr, int mo, int dy)
 
   day = 0;
   for( i = 0; i < mo-1; i++ )
-	day += days[i];
+    day += days[i];
   day = day + dy;
 
   /* Leap year correction */
   if( (yr%4 == 0) && ((yr%100 != 0) || (yr%400 == 0)) && (mo>2) )
-	day++;
+    day++;
 
   return( day );
 
@@ -236,9 +236,9 @@ Julian_Date(struct tm *cdate)
   double julian_date;
 
   julian_date = Julian_Date_of_Year(cdate->tm_year + 1900) +
-	DOY(cdate->tm_year + 1900, cdate->tm_mon + 1, cdate->tm_mday) +
-	Fraction_of_Day(cdate->tm_hour, cdate->tm_min, cdate->tm_sec) +
-	5.787037e-07; /* Round up to 0.1 sec */
+    DOY(cdate->tm_year + 1900, cdate->tm_mon + 1, cdate->tm_mday) +
+    Fraction_of_Day(cdate->tm_hour, cdate->tm_min, cdate->tm_sec) +
+    5.787037e-07; /* Round up to 0.1 sec */
 
   return( julian_date );
 
@@ -510,7 +510,7 @@ Theta(double julian_utc, double lon)
 
   t=(julian_utc-2451545.)/36525.;
   teg=280.46061837+360.98564736629*(julian_utc-2451545.)+
-	(0.000387933*t-t*t/38710000)*t;
+    (0.000387933*t-t*t/38710000)*t;
   th=Radians(teg+lon);
 
   th=FMod2p(th);
