@@ -25,11 +25,11 @@
 Sign( double arg )
 {
   if( arg > 0.0 )
-	return( 1 );
+    return( 1 );
   else if( arg < 0.0 )
-	return( -1 );
+    return( -1 );
   else
-	return( 0 );
+    return( 0 );
 
 } /* End of Sign() */
 
@@ -86,9 +86,9 @@ Degrees( double arg )
 ArcSin( double arg )
 {
   if( fabs(arg) >= 1.0 )
-	return( Sign(arg)*pio2 );
+    return( Sign(arg)*pio2 );
   else
-	return( atan(arg/sqrt(1-arg*arg)) );
+    return( atan(arg/sqrt(1-arg*arg)) );
 
 } /* End of ArcSin() */
 
@@ -265,22 +265,22 @@ AcTan( double sinx, double cosx )
 {
   if(cosx == 0.0)
   {
-	if(sinx > 0.0)
-	  return (pio2);
-	else
-	  return (x3pio2);
+    if(sinx > 0.0)
+      return (pio2);
+    else
+      return (x3pio2);
   }
   else
   {
-	if(cosx > 0.0)
-	{
-	  if(sinx > 0.0)
-		return ( atan(sinx/cosx) );
-	  else
-		return ( twopi + atan(sinx/cosx) );
-	}
-	else
-	  return ( pi + atan(sinx/cosx) );
+    if(cosx > 0.0)
+    {
+      if(sinx > 0.0)
+        return ( atan(sinx/cosx) );
+      else
+        return ( twopi + atan(sinx/cosx) );
+    }
+    else
+      return ( pi + atan(sinx/cosx) );
   }
 
 } /* End of AcTan() */
@@ -419,23 +419,23 @@ double Atof( const char *nptr )
   /* Find locale-dependent decimal point character */
   if( first_call )
   {
-	struct lconv *lcnv;
-	lcnv = localeconv();
-	dp = *lcnv->decimal_point;
-	first_call = FALSE;
+    struct lconv *lcnv;
+    lcnv = localeconv();
+    dp = *lcnv->decimal_point;
+    first_call = FALSE;
   }
 
   /* Look for a . or , decimal point character
    * in the supplied number buffer (string) */
   len = strlen( nptr );
   for( idx = 0; idx < (int)len; idx++ )
-	if( (nptr[idx] == ',') || (nptr[idx] == '.') )
-	  break;
+    if( (nptr[idx] == ',') || (nptr[idx] == '.') )
+      break;
 
   /* Create temporary string to modify decimal point */
   mem_alloc( (void **)&s, len + 1, "for temp in Atof()" );
   if( s == NULL ) return( d );
-  strncpy( s, nptr, len );
+  strcpy( s, nptr );
   s[ len ] = '\0';
 
   /* If a decimal point character is found, replace */
