@@ -26,8 +26,8 @@
 Load_Config( gpointer data )
 {
   char
-	rc_fpath[64], /* File path to xsatcomrc */
-	line[81];     /* Buffer for Load_Line  */
+    rc_fpath[64], /* File path to xsatcomrc */
+    line[81];     /* Buffer for Load_Line  */
 
   /* Config file pointer */
   FILE *xsatcomrc;
@@ -37,126 +37,126 @@ Load_Config( gpointer data )
 
   /* Setup file path to xsatcomrc */
   snprintf( rc_fpath, sizeof(rc_fpath),
-	  "%s/.xsatcom/xsatcomrc", getenv("HOME") );
+      "%s/.xsatcom/xsatcomrc", getenv("HOME") );
 
   /* Open xsatcomrc file */
   xsatcomrc = fopen( rc_fpath, "r" );
   if( xsatcomrc == NULL )
   {
-	perror( rc_fpath );
-	Error_Dialog(
-		_("Failed to open xsatcomrc file\n"\
-		  "Quit xsatcom and correct"), FATAL );
-	return( FALSE );
+    perror( rc_fpath );
+    Error_Dialog(
+        _("Failed to open xsatcomrc file\n"\
+          "Quit xsatcom and correct"), FATAL );
+    return( FALSE );
   }
 
   /*** Read runtime configuration data ***/
 
   /* Read Transceiver type for  CAT, abort if EOF */
   if( Load_Line(line, xsatcomrc, 80,
-		_("Transceiver type for CAT"), TRUE ) != SUCCESS )
-	return( FALSE );
+        _("Transceiver type for CAT"), TRUE ) != SUCCESS )
+    return( FALSE );
   if( strcmp(line, "FT847") == 0 )
-	rc_data.tcvr_type = FT847;
+    rc_data.tcvr_type = FT847;
   else if( strcmp(line, "FT857") == 0 )
-	rc_data.tcvr_type = FT857;
+    rc_data.tcvr_type = FT857;
   else if( strcmp(line, "K2") == 0 )
-	rc_data.tcvr_type = K2;
+    rc_data.tcvr_type = K2;
   else if( strcmp(line, "K3") == 0 )
-	rc_data.tcvr_type = K3;
+    rc_data.tcvr_type = K3;
   else if( strcmp(line, "NONE") == 0 )
-	rc_data.tcvr_type = NONE;
+    rc_data.tcvr_type = NONE;
   else
   {
-	rc_data.tcvr_type = NONE;
-	fclose( xsatcomrc );
-	Error_Dialog(
-		_("Error reading Transceiver type\n"\
-		  "Quit and correct xsatcomrc"), FATAL );
-	return( FALSE );
+    rc_data.tcvr_type = NONE;
+    fclose( xsatcomrc );
+    Error_Dialog(
+        _("Error reading Transceiver type\n"\
+          "Quit and correct xsatcomrc"), FATAL );
+    return( FALSE );
   }
 
   /* Read Transceiver serial device, abort on error */
   if( Load_Line(line, xsatcomrc, 80, _("Transceiver Serial"), TRUE) != SUCCESS )
-	return( FALSE );
+    return( FALSE );
   Strlcpy( rc_data.cat_serial, line, sizeof(rc_data.cat_serial) );
 
   /* Read Rotor serial device, abort on error */
   if( Load_Line(line, xsatcomrc, 80, _("Rotor Serial"), TRUE) != SUCCESS )
-	return( FALSE );
+    return( FALSE );
   Strlcpy( rc_data.rotor_serial, line, sizeof(rc_data.rotor_serial) );
 
   /* Read Rotor low resolution, abort on error */
   if( Load_Line(line, xsatcomrc, 80, _("Rotor Low resolution"), TRUE) != SUCCESS )
-	return( FALSE );
+    return( FALSE );
   rc_data.low_resol = atoi(line);
 
   /* Read Rotor med resolution, abort on error */
   if( Load_Line(line, xsatcomrc, 80, _("Rotor Medium Resolution"), TRUE) != SUCCESS )
-	return( FALSE );
+    return( FALSE );
   rc_data.med_resol = atoi(line);
 
   /* Read Rotor high resolution, abort on error */
   if( Load_Line(line, xsatcomrc, 80, _("Rotor High Resolution"), TRUE) != SUCCESS )
-	return( FALSE );
+    return( FALSE );
   rc_data.high_resol = atoi(line);
 
   /* Read Azimuth parking position, abort on error */
   if( Load_Line(line, xsatcomrc, 80, _("Azimuth Parking Position"), TRUE) != SUCCESS )
-	return( FALSE );
+    return( FALSE );
   rc_data.azim_parking = atoi(line);
 
   /* Read Elevation parking position, abort on error */
   if( Load_Line(line, xsatcomrc, 80, _("Elevation Parking Position"), TRUE) != SUCCESS )
-	return( FALSE );
+    return( FALSE );
   rc_data.elev_parking = atoi(line);
 
   /* Read Rotor Azimuth offset, abort on error */
   if( Load_Line(line, xsatcomrc, 80, _("Rotor Azimuth Offset"), TRUE) != SUCCESS )
-	return( FALSE );
+    return( FALSE );
   rc_data.azim_offset = atoi(line);
 
   /* Read AOS search angle step, abort on error */
   if( Load_Line(line, xsatcomrc, 80, _("AOS Search Angle Step"), TRUE) != SUCCESS )
-	return( FALSE );
+    return( FALSE );
   rc_data.angle_step = atoi(line);
 
   /* Read AOS search time step, abort on error */
   if( Load_Line(line, xsatcomrc, 80, _("AOS Search Time Step"), TRUE) != SUCCESS )
-	return( FALSE );
+    return( FALSE );
   rc_data.time_step = atoi(line);
 
   /* Read AOS search Horizon threshold, abort on error */
   if( Load_Line(line, xsatcomrc, 80, _("AOS Search Horizon Threshold"), TRUE) != SUCCESS )
-	return( FALSE );
+    return( FALSE );
   rc_data.horizon = Atof(line);
 
   /* Read xplanet directory, abort on error */
   if( Load_Line(line, xsatcomrc, 80,
-		_("Xplanet Directory"), TRUE) != SUCCESS )
-	return( FALSE );
+        _("Xplanet Directory"), TRUE) != SUCCESS )
+    return( FALSE );
   line[31] = '\0';
   Strlcpy( rc_data.xplanet_config, line,
-	  sizeof(rc_data.xplanet_config) );
+      sizeof(rc_data.xplanet_config) );
   Strlcpy( rc_data.xplanet_marker, line,
-	  sizeof(rc_data.xplanet_marker) );
+      sizeof(rc_data.xplanet_marker) );
   Strlcpy( rc_data.xplanet_gcarcs, line,
-	  sizeof(rc_data.xplanet_gcarcs) );
+      sizeof(rc_data.xplanet_gcarcs) );
   Strlcpy( rc_data.xplanet_satfile, line,
-	  sizeof(rc_data.xplanet_satfile) );
+      sizeof(rc_data.xplanet_satfile) );
   Strlcat( rc_data.xplanet_config, XPLANET_CONFIG,
-	  sizeof(rc_data.xplanet_config) );
+      sizeof(rc_data.xplanet_config) );
   Strlcat( rc_data.xplanet_marker, XPLANET_MARKER,
-	  sizeof(rc_data.xplanet_marker) );
+      sizeof(rc_data.xplanet_marker) );
   Strlcat( rc_data.xplanet_gcarcs, XPLANET_GCARCS,
-	  sizeof(rc_data.xplanet_gcarcs) );
+      sizeof(rc_data.xplanet_gcarcs) );
   Strlcat( rc_data.xplanet_satfile, XPLANET_SATFLE,
-	  sizeof(rc_data.xplanet_satfile) );
+      sizeof(rc_data.xplanet_satfile) );
 
   /* Read xplanet command, abort on error */
   if( Load_Line(line, xsatcomrc, 80,
-		_("Xplanet Command"), TRUE) != SUCCESS )
-	return( FALSE );
+        _("Xplanet Command"), TRUE) != SUCCESS )
+    return( FALSE );
   size_t s = sizeof( rc_data.xplanet_command );
   Strlcpy( rc_data.xplanet_command, "xplanet ", s );
   Strlcat( rc_data.xplanet_command, line, s );
@@ -166,16 +166,16 @@ Load_Config( gpointer data )
 
   /* Read WGF constant selection, abort on error */
   if( Load_Line(line, xsatcomrc, 80,
-		_("WGF Constant Selection"), TRUE) != SUCCESS )
-	return( FALSE );
+        _("WGF Constant Selection"), TRUE) != SUCCESS )
+    return( FALSE );
   rc_data.wgf = (char)atoi( line );
   if( (rc_data.wgf < 0) || (rc_data.wgf > 2) )
   {
-	fclose( xsatcomrc );
-	Error_Dialog(
-		_("Error reading WGF selection\n"\
-		  "Quit xsatcom and correct"), FATAL );
-	return( FALSE );
+    fclose( xsatcomrc );
+    Error_Dialog(
+        _("Error reading WGF selection\n"\
+          "Quit xsatcom and correct"), FATAL );
+    return( FALSE );
   }
   getgravconst();
 
@@ -183,19 +183,19 @@ Load_Config( gpointer data )
   error = Load_Observer_Data();
   if( strcmp(error, "OK!") != 0 )
   {
-	fclose( xsatcomrc );
-	Error_Dialog( error, FATAL );
-	return( FALSE );
+    fclose( xsatcomrc );
+    Error_Dialog( error, FATAL );
+    return( FALSE );
   }
   else
   {
-	error = Load_Database_Tle_Data();
-	if( strcmp(error, "OK!") != 0 )
-	{
-	  fclose( xsatcomrc );
-	  Error_Dialog( error, FATAL );
-	  return( FALSE );
-	}
+    error = Load_Database_Tle_Data();
+    if( strcmp(error, "OK!") != 0 )
+    {
+      fclose( xsatcomrc );
+      Error_Dialog( error, FATAL );
+      return( FALSE );
+    }
   }
 
   ClearFlag( DOPPLER_DISABLED );
@@ -217,92 +217,91 @@ Abort_On_Error( int why )
 {
   switch( why )
   {
-	case -1 :
-	  return(_("Error reading ~/.xsatcom/xsatcom.tle"\
-			"\nPlease quit and correct"));
+    case -1 :
+      return(_("Error reading ~/.xsatcom/xsatcom.tle"\
+            "\nPlease quit and correct"));
 
-	case -2 :
-	  return(_("Incorrect number of lines in"\
-			"\n~/.xsatcom/xsatcom.tle file"\
-			"\nPlease quit and correct"));
+    case -2 :
+      return(_("Incorrect number of lines in"\
+            "\n~/.xsatcom/xsatcom.tle file"\
+            "\nPlease quit and correct"));
 
-	case -3 :
-	  return(_("Invalid TLE set in"\
-			"\n~/.xsatcom/xsatcom.tle"\
-			"\nPlease quit and correct"));
+    case -3 :
+      return(_("Invalid TLE set in"\
+            "\n~/.xsatcom/xsatcom.tle"\
+            "\nPlease quit and correct"));
 
-	case -4 :
-	  return(_("Error reading ~/.xsatcom/xsatcom.obs"\
-			"\nPlease quit and correct"));
+    case -4 :
+      return(_("Error reading ~/.xsatcom/xsatcom.obs"\
+            "\nPlease quit and correct"));
 
-	case -5 :
-	  return(_("No valid observer location name found"\
-			"\nin ~/.xsatcom/xsatcom.obs file"\
-			"\nPlease quit and correct"));
+    case -5 :
+      return(_("No valid observer location name found"\
+            "\nin ~/.xsatcom/xsatcom.obs file"\
+            "\nPlease quit and correct"));
 
-	case -6 :
-	  return(_("Invalid observer location data"\
-			"\nin ~/.xsatcom/xsatcom.obs file"\
-			"\nPlease quit and correct"));
+    case -6 :
+      return(_("Invalid observer location data"\
+            "\nin ~/.xsatcom/xsatcom.obs file"\
+            "\nPlease quit and correct"));
 
-	case -7 :
-	  return(_("Conflicting Grid Locator/Position data"\
-			"\nin ~/.xsatcom/xsatcom.obs file"\
-			"\nPlease quit and correct"));
+    case -7 :
+      return(_("Conflicting Grid Locator/Position data"\
+            "\nin ~/.xsatcom/xsatcom.obs file"\
+            "\nPlease quit and correct"));
 
-	case -11 :
-	  return(_("Error reading ~/.xsatcom/xsatcom.sat"\
-			"\nPlease quit and correct"));
+    case -11 :
+      return(_("Error reading ~/.xsatcom/xsatcom.sat"\
+            "\nPlease quit and correct"));
 
-	case -12 :
-	  return(_("No satellite names found in"\
-			"\n~/.xsatcom/xsatcom.sat"\
-			"\nPlease quit and correct"));
+    case -12 :
+      return(_("No satellite names found in"\
+            "\n~/.xsatcom/xsatcom.sat"\
+            "\nPlease quit and correct"));
 
-	case -13 :
-	  return(_("No matching satellite name"\
-			"\nfound in ~/.xsatcom/xsatcom.tle"\
-			"\nPlease quit and correct"));
+    case -13 :
+      return(_("No matching satellite name"\
+            "\nfound in ~/.xsatcom/xsatcom.tle"\
+            "\nPlease quit and correct"));
 
-	case -14 :
-	  return(_("Satellite transponder data in"\
-			"\n~/.xsatcom/xsatcom.sat incomplete"\
-			"\nPlease quit and correct"));
+    case -14 :
+      return(_("Satellite transponder data in"\
+            "\n~/.xsatcom/xsatcom.sat incomplete"\
+            "\nPlease quit and correct"));
 
-	case -15 :
-	  return(_("Transponder passband flag in"\
-			"\n~/.xsatcom/xsatcom.sat invalid"\
-			"\nPlease quit and correct"));
+    case -15 :
+      return(_("Transponder passband flag in"\
+            "\n~/.xsatcom/xsatcom.sat invalid"\
+            "\nPlease quit and correct"));
 
-	case -17 :
-	  return( _("Failed to open file"\
-			"\n~/.xsatcom/xsatcom.tle"\
-			"\nPlease quit and correct"));
+    case -17 :
+      return( _("Failed to open file ~/.xsatcom/xsatcom.tle"\
+            "\nPlease quit and run get_tle.sh to download"));
 
-	case -18 :
-	  return( _("Failed to open file"\
-			"\n~/.xsatcom/xsatcom.sat"\
-			"\nPlease quit and correct"));
+    case -18 :
+      return( _("Failed to open file"\
+            "\n~/.xsatcom/xsatcom.sat"\
+            "\nPlease quit and correct"));
 
-	case -19 :
-	  return( _("Failed to open file"\
-			"\n~/.xsatcom/xsatcom.obs"\
-			"\nPlease quit and correct"));
+    case -19 :
+      return( _("Failed to open file"\
+            "\n~/.xsatcom/xsatcom.obs"\
+            "\nPlease quit and correct"));
 
-	case -20 :
-	  return( _("No Transponder Mode name found"\
-			"\nin ~/.xsatcom/xsatcom.sat"\
-			"\nPlease quit and correct") );
+    case -20 :
+      return( _("No Transponder Mode name found"\
+            "\nin ~/.xsatcom/xsatcom.sat"\
+            "\nPlease quit and correct") );
 
-	case -22 :
-	  return(_("Invalid satellite name data"\
-			"\nin ~/.xsatcom/xsatcom.obs file"\
-			"\nPlease quit and correct"));
+    case -22 :
+      return(_("Invalid satellite name data"\
+            "\nin ~/.xsatcom/xsatcom.obs file"\
+            "\nPlease quit and correct"));
 
-	case -23 :
-	  return(_("Error in sgp4() routine"\
-			"\n(Details printed to stderr)"\
-			"\nPlease quit and correct"));
+    case -23 :
+      return(_("Error in sgp4() routine"\
+            "\n(Details printed to stderr)"\
+            "\nPlease quit and correct"));
 
   } /* End of switch( why ) */
 
@@ -323,26 +322,26 @@ Cleanup( void )
   /* Make current position the new demand */
   if( isFlagSet(ROTORS_ENABLED) )
   {
-	int azim_dir, elev_dir;
+    int azim_dir, elev_dir;
 
-	Rotor_Read_Direction( &azim_dir, &elev_dir );
-	Manual_Position_Rotors( azim_dir, elev_dir );
-	Disable_Tracking();
+    Rotor_Read_Direction( &azim_dir, &elev_dir );
+    Manual_Position_Rotors( azim_dir, elev_dir );
+    Disable_Tracking();
   }
 
   /* Return transceiver to original status */
   if( isFlagSet(CAT_SETUP) )
-	Close_Tcvr_Serial();
+    Close_Tcvr_Serial();
 
   /* Delete xplanet files */
   if( isFlagSet(XPLANET_PLOT) )
   {
-	unlink( rc_data.xplanet_marker );
-	unlink( rc_data.xplanet_gcarcs );
-	unlink( rc_data.xplanet_satfile );
-	unlink( rc_data.xplanet_config );
-	if( system(_("pkill xplanet")) == -1 )
-	  fprintf( stderr, "xsatcom: system() function call failed\n" );
+    unlink( rc_data.xplanet_marker );
+    unlink( rc_data.xplanet_gcarcs );
+    unlink( rc_data.xplanet_satfile );
+    unlink( rc_data.xplanet_config );
+    if( system(_("pkill xplanet")) == -1 )
+      fprintf( stderr, "xsatcom: system() function call failed\n" );
   }
 
 } /* Cleanup() */
@@ -431,10 +430,10 @@ Usage( void )
   fprintf( stderr, "%s\n", _("Usage: xwxapt [-hv]") );
 
   fprintf( stderr, "%s\n",
-	  _("       -h: Print this usage information and exit"));
+      _("       -h: Print this usage information and exit"));
 
   fprintf( stderr, "%s\n",
-	  _("       -v: Print version number and exit"));
+      _("       -v: Print version number and exit"));
 
 } /* End of Usage() */
 
@@ -460,10 +459,10 @@ Strlcpy( char *dest, const char *src, size_t n )
   /* Copy till terminating null of src or to n-1 */
   while( (ch != '\0') && (n > 0) )
   {
-	dest[idx] = src[idx];
-	idx++;
-	ch = src[idx];
-	n--;
+    dest[idx] = src[idx];
+    idx++;
+    ch = src[idx];
+    n--;
   }
 
   /* Terminate dest string */
@@ -492,9 +491,9 @@ Strlcat( char *dest, const char *src, size_t n )
   /* Find terminating null of dest */
   while( (n > 0) && (ch != '\0') )
   {
-	idd++;
-	ch = dest[idd];
-	n--; /* Count remaining char's in dest */
+    idd++;
+    ch = dest[idd];
+    n--; /* Count remaining char's in dest */
   }
 
   /* Copy n-1 chars to leave room for terminating null */
@@ -502,11 +501,11 @@ Strlcat( char *dest, const char *src, size_t n )
   ch = src[ids];
   while( (n > 0) && (ch != '\0') )
   {
-	dest[idd] = src[ids];
-	ids++;
-	ch = src[ids];
-	idd++;
-	n--;
+    dest[idd] = src[ids];
+    ids++;
+    ch = src[ids];
+    idd++;
+    n--;
   }
 
   /* Terminate dest string */
@@ -527,15 +526,15 @@ Strlcat( char *dest, const char *src, size_t n )
 Load_Line( char *buff, FILE *pfile, int max_chr, char *messg, gboolean eof_err )
 {
   int
-	num_chr, /* Number of characters read, excluding lf/cr */
-	chr;     /* Character read by getc() */
+    num_chr, /* Number of characters read, excluding lf/cr */
+    chr;     /* Character read by getc() */
   char error_mesg[MESG_SIZE];
   size_t s = sizeof(error_mesg);
 
   /* Prepare error message */
   snprintf( error_mesg, s,
-	  _("Error reading %s\n"\
-		"Premature EOF (End Of File)"), messg );
+      _("Error reading %s\n"\
+        "Premature EOF (End Of File)"), messg );
 
   /* Clear buffer at start */
   buff[0] = '\0';
@@ -545,46 +544,46 @@ Load_Line( char *buff, FILE *pfile, int max_chr, char *messg, gboolean eof_err )
   chr = fgetc(pfile);
   if( eof_err && (chr == EOF) )
   {
-	fprintf( stderr, "xsatcom: %s\n", error_mesg );
-	fclose( pfile );
-	Error_Dialog( error_mesg, FATAL );
-	return( EOF );
+    fprintf( stderr, "xsatcom: %s\n", error_mesg );
+    fclose( pfile );
+    Error_Dialog( error_mesg, FATAL );
+    return( EOF );
   }
 
   /* Ignore commented lines, white spaces and eol/cr */
   while(
-	  (chr == '#') ||
-	  (chr == ' ') ||
-	  (chr == CR ) ||
-	  (chr == LF ) )
+      (chr == '#') ||
+      (chr == ' ') ||
+      (chr == CR ) ||
+      (chr == LF ) )
   {
-	/* Go to the end of line (look for LF or CR) */
-	while( (chr != CR) && (chr != LF) )
-	{
-	  /* Get next character, return error if chr = EOF */
-	  chr = fgetc(pfile);
-	  if( eof_err && (chr == EOF) )
-	  {
-		fprintf( stderr, "xsatcom: %s\n", error_mesg );
-		fclose( pfile );
-		Error_Dialog( error_mesg, FATAL );
-		return( EOF );
-	  }
-	}
+    /* Go to the end of line (look for LF or CR) */
+    while( (chr != CR) && (chr != LF) )
+    {
+      /* Get next character, return error if chr = EOF */
+      chr = fgetc(pfile);
+      if( eof_err && (chr == EOF) )
+      {
+        fprintf( stderr, "xsatcom: %s\n", error_mesg );
+        fclose( pfile );
+        Error_Dialog( error_mesg, FATAL );
+        return( EOF );
+      }
+    }
 
-	/* Dump any CR/LF remaining */
-	while( (chr == CR) || (chr == LF) )
-	{
-	  /* Get next character, return error if chr = EOF */
-	  chr = fgetc(pfile);
-	  if( eof_err && (chr == EOF) )
-	  {
-		fprintf( stderr, "xsatcom: %s\n", error_mesg );
-		fclose( pfile );
-		Error_Dialog( error_mesg, FATAL );
-		return( EOF );
-	  }
-	}
+    /* Dump any CR/LF remaining */
+    while( (chr == CR) || (chr == LF) )
+    {
+      /* Get next character, return error if chr = EOF */
+      chr = fgetc(pfile);
+      if( eof_err && (chr == EOF) )
+      {
+        fprintf( stderr, "xsatcom: %s\n", error_mesg );
+        fclose( pfile );
+        Error_Dialog( error_mesg, FATAL );
+        return( EOF );
+      }
+    }
 
   } /* End of while( (chr == '#') || ... */
 
@@ -592,33 +591,33 @@ Load_Line( char *buff, FILE *pfile, int max_chr, char *messg, gboolean eof_err )
    * number of characters = max_chr or EOF or CR/LF */
   while( num_chr < max_chr )
   {
-	if( chr == HT ) chr = WS;
+    if( chr == HT ) chr = WS;
 
-	/* If LF/CR reached before filling buffer, return line */
-	if( (chr == LF) || (chr == CR) ) break;
+    /* If LF/CR reached before filling buffer, return line */
+    if( (chr == LF) || (chr == CR) ) break;
 
-	/* Enter new character to line buffer */
-	buff[num_chr++] = (char)chr;
+    /* Enter new character to line buffer */
+    buff[num_chr++] = (char)chr;
 
-	/* Get next character */
-	chr = fgetc( pfile );
-	if( chr == EOF )
-	  break;
+    /* Get next character */
+    chr = fgetc( pfile );
+    if( chr == EOF )
+      break;
 
   } /* End of while( num_chr < max_chr ) */
 
   /* Abort if end of line not reached at max_chr */
   if( (num_chr == max_chr) && (chr != LF) && (chr != CR) )
   {
-	/* Terminate buffer as a string */
-	buff[num_chr] = '\0';
-	snprintf( error_mesg, s,
-		_("Error reading %s\n"\
-		  "Line longer than 80 characters"), messg );
-	fprintf( stderr, "xsatcom: %s\n%s\n", error_mesg, buff );
-	fclose( pfile );
-	Error_Dialog( error_mesg, FATAL );
-	return( ERROR );
+    /* Terminate buffer as a string */
+    buff[num_chr] = '\0';
+    snprintf( error_mesg, s,
+        _("Error reading %s\n"\
+          "Line longer than 80 characters"), messg );
+    fprintf( stderr, "xsatcom: %s\n%s\n", error_mesg, buff );
+    fclose( pfile );
+    Error_Dialog( error_mesg, FATAL );
+    return( ERROR );
   }
 
   /* Terminate buffer as a string and remove trailing blanks */
@@ -626,14 +625,14 @@ Load_Line( char *buff, FILE *pfile, int max_chr, char *messg, gboolean eof_err )
   num_chr--;
   while( (num_chr >= 0) && (buff[num_chr] == WS) )
   {
-	buff[num_chr] = '\0';
-	num_chr--;
+    buff[num_chr] = '\0';
+    num_chr--;
   }
 
   if( chr == EOF )
-	return( EOF_NORM );
+    return( EOF_NORM );
   else
-	return( SUCCESS );
+    return( SUCCESS );
 
 } /* End of Load_Line() */
 
@@ -648,10 +647,10 @@ void mem_alloc( void **ptr, size_t req, gchar *str )
   *ptr = malloc( req );
   if( *ptr == NULL )
   {
-	snprintf( mesg, sizeof(mesg),
-		_("Memory allocation denied %s"), str );
-	fprintf( stderr, "%s\n", mesg );
-	Error_Dialog( mesg, FATAL );
+    snprintf( mesg, sizeof(mesg),
+        _("Memory allocation denied %s"), str );
+    fprintf( stderr, "%s\n", mesg );
+    Error_Dialog( mesg, FATAL );
   }
 
 } /* End of mem_alloc() */
@@ -665,10 +664,10 @@ void mem_realloc( void **ptr, size_t req, gchar *str )
   *ptr = realloc( *ptr, req );
   if( *ptr == NULL )
   {
-	snprintf( mesg, sizeof(mesg),
-		_("Memory re-allocation denied %s"), str );
-	fprintf( stderr, "%s\n", mesg );
-	Error_Dialog( mesg, FATAL );
+    snprintf( mesg, sizeof(mesg),
+        _("Memory re-allocation denied %s"), str );
+    fprintf( stderr, "%s\n", mesg );
+    Error_Dialog( mesg, FATAL );
   }
 
 } /* End of mem_realloc() */
@@ -678,7 +677,7 @@ void mem_realloc( void **ptr, size_t req, gchar *str )
 void free_ptr( void **ptr )
 {
   if( *ptr != NULL )
-	free( *ptr );
+    free( *ptr );
   *ptr = NULL;
 
 } /* End of free_ptr() */
